==========
Attributes
==========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

   Series.cat
   Series.dt
   Series.dtype
   Series.inner_dtype
   Series.list
   Series.name
   Series.shape
   Series.str
   Series.flags
